@@ -3,8 +3,23 @@
 #![allow(non_camel_case_types)]		// turn off warning about upper camel case type name
 #![allow(non_upper_case_globals)]	// turn off warning about global non upper camel name
 #![allow(dead_code)]
+#![feature(generic_const_exprs)]
 
 
 pub mod BlockCipher;
 pub mod StreamCipher;
 
+
+pub use BlockCipher::*;
+
+
+
+
+
+
+
+// let cipher = Aes128Cipher::New (&key);
+
+// let blockCipher = BlockCipher<Aes128Cipher>::New (BlockMode);
+
+
